@@ -20,17 +20,17 @@
 #ifndef REPORTASSISTANTPAGES__BASE__H
 #define REPORTASSISTANTPAGES__BASE__H
 
+#include <QtCore/QPointer>
+
 #include "reportassistantdialog.h"
 #include "reportassistantpage.h"
 
-#include "backtracewidget.h"
-
 #include "ui_assistantpage_introduction.h"
 #include "ui_assistantpage_bugawareness.h"
 #include "ui_assistantpage_conclusions.h"
 #include "ui_assistantpage_conclusions_dialog.h"
 
-#include <QtCore/QPointer>
+class BacktraceWidget;
 
 /** Introduction page **/
 class IntroductionPage: public ReportAssistantPage
@@ -104,8 +104,8 @@ private:
 
     QPointer<KDialog>                       m_infoDialog;
 
-    bool                                    isBKO;
-    bool                                    needToReport;
+    bool                                    m_isBKO;
+    bool                                    m_needToReport;
 
 Q_SIGNALS:
     void finished(bool);
